@@ -8,7 +8,7 @@ BEGIN {
   use Math::Complex;
   my @M_Complex = qw(i Re Im rho theta arg cplx cplxe);
   our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
-  $VERSION     = 0.22;
+  $VERSION     = 0.23;
   @ISA         = qw(Exporter);
   @EXPORT      = qw(&entangle &p_op &p_func &q_logic
 		    &save_state &restore_state);
@@ -27,28 +27,27 @@ $Quantum::Entanglement::conform = 0; # true=> strives for truth when observing
 # Overload routines
 # parallel operators and functions
 # methods for saving and restoring state
-# pod, but maybe not up to the minute pod
-#             this module is under construction, as it were
+# pod
 
-=begin pretty_pictures
-
-Things look like this:
-
-$state_info   = [ \-1, ref1, ref2, ... ];
-                        /
-                      |/----<----\
-                      /           \
-entangled var1 = [offset, ref to offset ];
-
-where ref1 and ref to offset are the SAME reference and
-where offset is the element number of val1 in each state:
-
-$states = [
-	   [prob1, val1, prob2, val2],
-	   [prob1, val1, prob2, val2],
-	  ];
-
-=cut pretty_pictures
+# =begin pretty_pictures
+#
+# Things look like this:
+#
+# $state_info   = [ \-1, ref1, ref2, ... ];
+#                        /
+#                      |/----<----\
+#                      /           \
+# entangled var1 = [offset, ref to offset ];
+#
+# where ref1 and ref to offset are the SAME reference and
+# where offset is the element number of val1 in each state:
+#
+# $states = [
+#	    [prob1, val1, prob2, val2],
+#	    [prob1, val1, prob2, val2],
+#	    ];
+#
+# =cut pretty_pictures
 
 my $state_info =[\-1]; # these contain the global state space
 my $states = [];
